@@ -1,6 +1,7 @@
 /* Locations for Bison
 
-   Copyright (C) 2002, 2004-2015, 2018 Free Software Foundation, Inc.
+   Copyright (C) 2002, 2004-2015, 2018-2019 Free Software Foundation,
+   Inc.
 
    This file is part of Bison, the GNU Compiler Compiler.
 
@@ -125,6 +126,9 @@ location_cmp (location a, location b)
   return res;
 }
 
+/* Whether this is the empty location.  */
+bool location_empty (location loc);
+
 /* LOC_STR must be formatted as 'file:line.column', it will be modified.  */
 void boundary_set_from_string (boundary *bound, char *loc_str);
 
