@@ -1,7 +1,7 @@
 /* Output a graph of the generated parser, for Bison.
 
-   Copyright (C) 2000, 2006, 2009-2015, 2018 Free Software Foundation,
-   Inc.
+   Copyright (C) 2000, 2006, 2009-2015, 2018-2019 Free Software
+   Foundation, Inc.
 
    This file is part of Bison, the GNU Compiler Compiler.
 
