@@ -1,7 +1,7 @@
 /* Keep a unique copy of strings.
 
-   Copyright (C) 2002-2005, 2009-2015, 2018 Free Software Foundation,
-   Inc.
+   Copyright (C) 2002-2005, 2009-2015, 2018-2019 Free Software
+   Foundation, Inc.
 
    This file is part of Bison, the GNU Compiler Compiler.
 
